#!/usr/bin/env python3

# filestore: dmedia hashing protocol and file layout
# Copyright (C) 2011 Novacut Inc
#
# This file is part of `filestore`.
#
# `filestore` is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# `filestore` is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with `filestore`.  If not, see <http://www.gnu.org/licenses/>.
#
# Authors:
#   Jason Gerard DeRose <jderose@novacut.com>

import sys
import os
from os import path
import logging
import optparse

from benchmark import units_base10, Timer
import filestore


parser = optparse.OptionParser(
	usage='Usage: %prog SOURCE DESTINATION',
)
(options, args) = parser.parse_args()


if len(args) != 2:
    parser.print_usage()
    sys.exit('ERROR: must provide SOURCE and DESTINATION directories')
src = path.abspath(args[0])
dst = path.abspath(args[1])
if not path.isdir(src):
    parser.print_usage()
    sys.exit('ERROR: SOURCE is not a directory:\n  {!r}'.format(src))
if not path.isdir(dst):
    parser.print_usage()
    sys.exit('ERROR: DESTINATION is not a directory:\n  {!r}'.format(dst))


dotname = '.dmedia-stress'
fs = filestore.FileStore(dst, dotname)


logging.basicConfig(
    filename=path.join(fs.base, 'stress-log.txt'),
    filemode='w',
    level=logging.DEBUG,
    format='\t'.join(['%(levelname)s', '%(message)s']),
)


total_bytes = 0
a = []

# Import
t1 = Timer()
for f in filestore.iter_files(src):
    if f.size == 0:  # FileStore doesn't store the zero byte file
        continue
    print(f.name)
    src_fp = open(f.name, 'rb')
    c = fs.import_file(src_fp)
    a.append(c)
    assert c.file_size == f.size
    total_bytes += c.file_size
    print('  _id: {}'.format(c.id))
    print('  file_size: {}'.format(units_base10(c.file_size)))
t1.done()

t2 = Timer()
for c in a:
    print('FileStore.verify({!r})'.format(c.id))
    fs.verify(c.id)
t2.done()

t3 = Timer()
for c in a:
    print('FileStore.verify_iter({!r}, {!r}, <leaf_hashes>)'.format(c.id, c.file_size))
    for (i, leaf) in fs.verify_iter(c.id, c.file_size, c.leaf_hashes):
        pass
t3.done()

print('')
print('{} files, {}'.format(len(a), units_base10(total_bytes)))
print('FileStore.import_file() - {}'.format(t1.rate(total_bytes)))
print('FileStore.verify() - {}'.format(t2.rate(total_bytes)))
print('FileStore.verify_iter() - {}'.format(t3.rate(total_bytes)))
print('Browse the FileStore layout here:\n  {}'.format(fs.base))
